@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2002 Zope Corporation and Contributors. All Rights Reserved.
+# Copyright (c) 2002 Zope Foundation and Contributors.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -11,8 +11,6 @@
 #
 ##############################################################################
 """ Information about customizable actions.
-
-$Id: ActionInformation.py 105897 2009-11-20 07:57:56Z yuppie $
 """
 
 from UserDict import UserDict
@@ -24,6 +22,8 @@ from OFS.ObjectManager import IFAwareObjectManager
 from OFS.OrderedFolder import OrderedFolder
 from OFS.PropertyManager import PropertyManager
 from OFS.SimpleItem import SimpleItem
+from zope.component import getUtility
+from zope.globalrequest import getRequest
 from zope.i18nmessageid import Message
 from zope.interface import implements
 
@@ -31,9 +31,9 @@ from Products.CMFCore.Expression import Expression
 from Products.CMFCore.interfaces import IAction
 from Products.CMFCore.interfaces import IActionCategory
 from Products.CMFCore.interfaces import IActionInfo
+from Products.CMFCore.interfaces import IMembershipTool
 from Products.CMFCore.permissions import View
 from Products.CMFCore.utils import _checkPermission
-from Products.CMFCore.utils import getToolByName
 
 _unchanged = [] # marker
 
@@ -120,8 +120,12 @@ class Action(PropertyManager, SimpleItem):
         if isinstance(value, list):
             value = tuple(value)
         setattr(self, id, value)
-        if value and id.endswith('_expr'):
-            setattr( self, '%s_object' % id, Expression(value) )
+        if id.endswith('_expr'):
+            attr = '%s_object' % id
+            if value:
+                setattr(self, attr, Expression(value))
+            elif hasattr(self, attr):
+                delattr(self, attr)
 
     security.declarePrivate('getInfoData')
     def getInfoData(self):
@@ -149,6 +153,8 @@ class Action(PropertyManager, SimpleItem):
                     val = True
             elif id == 'i18n_domain':
                 continue
+            elif id == 'link_target':
+                val = val or None
             elif self.i18n_domain and id in ('title', 'description'):
                 val = Message(val, self.i18n_domain)
             lazy_map[id] = val
@@ -177,7 +183,7 @@ class ActionInfo(UserDict):
                 self.data.setdefault( 'title', self.data['name'] )
                 del self.data['name']
             self.data.setdefault( 'url', '' )
-            self.data.setdefault( 'link_target', '' )
+            self.data.setdefault( 'link_target', None )
             self.data.setdefault( 'icon', '' )
             self.data.setdefault( 'category', 'object' )
             self.data.setdefault( 'visible', True )
@@ -500,6 +506,9 @@ class ActionInformation( SimpleItem ):
         lazy_keys = []
         lazy_map = self.getMapping()
 
+        if not lazy_map['link_target']:
+            lazy_map['link_target'] = None
+
         if lazy_map['action']:
             lazy_map['url'] = self._getActionObject()
             lazy_keys.append('url')
@@ -527,7 +536,7 @@ InitializeClass( ActionInformation )
 
 
 def getOAI(context, object=None):
-    request = getattr(context, 'REQUEST', None)
+    request = getRequest()
     if request:
         cache = request.get('_oai_cache', None)
         if cache is None:
@@ -563,9 +572,9 @@ class oai:
 
     def __init__( self, tool, folder, object=None ):
         self.portal = portal = aq_parent(aq_inner(tool))
-        membership = getToolByName(tool, 'portal_membership')
-        self.isAnonymous = membership.isAnonymousUser()
-        self.user_id = membership.getAuthenticatedMember().getId()
+        mtool = getUtility(IMembershipTool)
+        self.isAnonymous = mtool.isAnonymousUser()
+        self.user_id = mtool.getAuthenticatedMember().getId()
         self.portal_url = portal.absolute_url()
         if folder is not None:
             self.folder_url = folder.absolute_url()
