@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2001 Zope Corporation and Contributors. All Rights Reserved.
+# Copyright (c) 2001 Zope Foundation and Contributors.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -11,15 +11,14 @@
 #
 ##############################################################################
 """ Basic membership tool.
-
-$Id: MembershipTool.py 103563 2009-09-04 23:04:10Z hannosch $
 """
 
 import logging
 from warnings import warn
 
-from AccessControl.SecurityInfo import ClassSecurityInfo
 from AccessControl.requestmethod import postonly
+from AccessControl.SecurityInfo import ClassSecurityInfo
+from AccessControl.SecurityManagement import getSecurityManager
 from AccessControl.User import nobody
 from Acquisition import aq_base
 from Acquisition import aq_inner
@@ -31,11 +30,17 @@ from OFS.Folder import Folder
 from Persistence import PersistentMapping
 from ZODB.POSException import ConflictError
 from zope.component import getUtility
+from zope.component import queryUtility
+from zope.globalrequest import getRequest
 from zope.interface import implements
+from ZPublisher.BaseRequest import RequestContainer
 
 from Products.CMFCore.exceptions import AccessControl_Unauthorized
 from Products.CMFCore.exceptions import BadRequest
+from Products.CMFCore.interfaces import ICookieCrumbler
+from Products.CMFCore.interfaces import IMemberDataTool
 from Products.CMFCore.interfaces import IMembershipTool
+from Products.CMFCore.interfaces import IRegistrationTool
 from Products.CMFCore.interfaces import ISiteRoot
 from Products.CMFCore.permissions import AccessContentsInformation
 from Products.CMFCore.permissions import ChangeLocalRoles
@@ -46,8 +51,7 @@ from Products.CMFCore.permissions import SetOwnPassword
 from Products.CMFCore.permissions import View
 from Products.CMFCore.utils import _checkPermission
 from Products.CMFCore.utils import _dtmldir
-from Products.CMFCore.utils import _getAuthenticatedUser
-from Products.CMFCore.utils import getToolByName
+from Products.CMFCore.utils import registerToolInterface
 from Products.CMFCore.utils import UniqueObject
 
 logger = logging.getLogger('CMFCore.MembershipTool')
@@ -94,13 +98,11 @@ class MembershipTool(UniqueObject, Folder):
     def setPassword(self, password, domains=None, REQUEST=None):
         '''Allows the authenticated member to set his/her own password.
         '''
-        # XXX: this method violates the rules for tools/utilities:
-        # it depends on a non-utility tool
-        registration = getToolByName(self, 'portal_registration', None)
         if not self.isAnonymousUser():
             member = self.getAuthenticatedMember()
-            if registration:
-                failMessage = registration.testPasswordValidity(password)
+            rtool = queryUtility(IRegistrationTool)
+            if rtool is not None:
+                failMessage = rtool.testPasswordValidity(password)
                 if failMessage is not None:
                     raise BadRequest(failMessage)
             member.setSecurityProfile(password=password, domains=domains)
@@ -113,7 +115,7 @@ class MembershipTool(UniqueObject, Folder):
         Returns the currently authenticated member object
         or the Anonymous User.  Never returns None.
         '''
-        u = _getAuthenticatedUser(self)
+        u = getSecurityManager().getUser()
         if u is None:
             u = nobody
         return self.wrapUser(u)
@@ -125,8 +127,6 @@ class MembershipTool(UniqueObject, Folder):
         Provides an opportunity for a portal_memberdata tool to retrieve and
         store member data independently of the user object.
         """
-        # XXX: this method violates the rules for tools/utilities:
-        # it depends on a non-utility tool
         b = getattr(u, 'aq_base', None)
         if b is None:
             # u isn't wrapped at all.  Wrap it in self.acl_users.
@@ -145,7 +145,7 @@ class MembershipTool(UniqueObject, Folder):
                         portal_role not in u.roles):
                     u.roles.append(portal_role)
 
-        mdtool = getToolByName(self, 'portal_memberdata', None)
+        mdtool = queryUtility(IMemberDataTool)
         if mdtool is not None:
             try:
                 u = mdtool.wrapUser(u)
@@ -205,9 +205,12 @@ class MembershipTool(UniqueObject, Folder):
     def getMembersFolder(self):
         """ Get the members folder object.
         """
-        parent = aq_parent( aq_inner(self) )
-        members = getattr(parent, 'Members', None)
-        return members
+        parent = aq_parent(aq_inner(self))
+        members_folder = getattr(parent, 'Members', None)
+        if members_folder is None:
+            return None
+        request_container = RequestContainer(REQUEST=getRequest())
+        return members_folder.__of__(request_container)
 
     security.declareProtected(ManagePortal, 'getMemberareaCreationFlag')
     def getMemberareaCreationFlag(self):
@@ -251,22 +254,15 @@ class MembershipTool(UniqueObject, Folder):
             return None
         if self.isAnonymousUser():
             return None
-        # Note: We can't use getAuthenticatedMember() and getMemberById()
-        # because they might be wrapped by MemberDataTool.
-        user = _getAuthenticatedUser(self)
-        user_id = user.getId()
-        if member_id in ('', user_id):
-            member = user
-            member_id = user_id
-        else:
-            if _checkPermission(ManageUsers, self):
-                uf = self._huntUserFolder(member_id, self)
-                if uf:
-                    member = uf.getUserById(member_id).__of__(uf)
-                else:
-                    raise ValueError('Member %s does not exist' % member_id)
-            else:
+        if member_id:
+            if not self.isMemberAccessAllowed(member_id):
                 return None
+            member = self.getMemberById(member_id)
+            if member is None:
+                return None
+        else:
+            member = self.getAuthenticatedMember()
+            member_id = member.getId()
         if hasattr( aq_base(members), member_id ):
             return None
         else:
@@ -307,7 +303,7 @@ class MembershipTool(UniqueObject, Folder):
         '''
         Returns 1 if the user is not logged in.
         '''
-        u = _getAuthenticatedUser(self)
+        u = getSecurityManager().getUser()
         if u is None or u.getUserName() == 'Anonymous User':
             return 1
         return 0
@@ -322,6 +318,18 @@ class MembershipTool(UniqueObject, Folder):
             object = getattr(object, subobjectName)
         return _checkPermission(permissionName, object)
 
+    security.declareProtected(ManageUsers, 'isMemberAccessAllowed')
+    def isMemberAccessAllowed(self, member_id):
+        """Check if the authenticated user is this member or an user manager.
+        """
+        sm = getSecurityManager()
+        user = sm.getUser()
+        if user is None:
+            return False
+        if member_id == user.getId():
+            return True
+        return sm.checkPermission(ManageUsers, self)
+
     security.declarePublic('credentialsChanged')
     def credentialsChanged(self, password, REQUEST=None):
         '''
@@ -330,25 +338,14 @@ class MembershipTool(UniqueObject, Folder):
         Note that this call should *not* cause any change at all to user
         databases.
         '''
-        # XXX: this method violates the rules for tools/utilities:
-        # it depends on self.REQUEST
-        if REQUEST is None:
-            REQUEST = self.REQUEST
-            warn("credentialsChanged should be called with 'REQUEST' as "
-                 "second argument. The BBB code will be removed in CMF 2.3.",
-                 DeprecationWarning, stacklevel=2)
-
         if not self.isAnonymousUser():
-            acl_users = self.acl_users
-            user = _getAuthenticatedUser(self)
+            user = getSecurityManager().getUser()
             name = user.getUserName()
             # this really does need to be the user name, and not the user id,
             # because we're dealing with authentication credentials
-            p = getattr(REQUEST, '_credentials_changed_path', None)
-            if p is not None:
-                # Use an interface provided by CookieCrumbler.
-                change = self.restrictedTraverse(p)
-                change(user, name, password)
+            cctool = queryUtility(ICookieCrumbler)
+            if cctool is not None:
+                cctool.credentialsChanged(user, name, password, REQUEST)
 
     security.declareProtected(ManageUsers, 'getMemberById')
     def getMemberById(self, id):
@@ -380,7 +377,7 @@ class MembershipTool(UniqueObject, Folder):
         """
         uf = self._huntUserFolder(member_id, context)
         if uf is not None:
-            return uf.getUserById(member_id)
+            return uf.getUserById(member_id).__of__(uf)
 
     def __getPUS(self):
         """ Retrieve the nearest user folder
@@ -406,13 +403,12 @@ class MembershipTool(UniqueObject, Folder):
         return map(self.wrapUser, self.acl_users.getUsers())
 
     security.declareProtected(ListPortalMembers, 'searchMembers')
-    def searchMembers( self, search_param, search_term ):
+    def searchMembers(self, search_param, search_term):
         """ Search the membership """
-        # XXX: this method violates the rules for tools/utilities:
-        # it depends on a non-utility tool
-        md = getToolByName( self, 'portal_memberdata' )
-
-        return md.searchMemberData( search_param, search_term )
+        mdtool = queryUtility(IMemberDataTool)
+        if mdtool is not None:
+            return mdtool.searchMemberData(search_param, search_term)
+        return None
 
     security.declareProtected(View, 'getCandidateLocalRoles')
     def getCandidateLocalRoles(self, obj):
@@ -423,7 +419,7 @@ class MembershipTool(UniqueObject, Folder):
         if _checkPermission(ManageUsers, obj):
             local_roles = self.getPortalRoles()
             if 'Manager' not in member_roles:
-                 local_roles.remove('Manager')
+                local_roles.remove('Manager')
         else:
             local_roles = [ role for role in member_roles
                             if role not in ('Member', 'Authenticated') ]
@@ -485,9 +481,6 @@ class MembershipTool(UniqueObject, Folder):
                       delete_localroles=1, REQUEST=None):
         """ Delete members specified by member_ids.
         """
-        # XXX: this method violates the rules for tools/utilities:
-        # it depends on a non-utility tool
-
         # Delete members in acl_users.
         acl_users = self.acl_users
         if _checkPermission(ManageUsers, acl_users):
@@ -507,7 +500,7 @@ class MembershipTool(UniqueObject, Folder):
                                  'permission for the underlying User Folder.')
 
         # Delete member data in portal_memberdata.
-        mdtool = getToolByName(self, 'portal_memberdata', None)
+        mdtool = queryUtility(IMemberDataTool)
         if mdtool is not None:
             for member_id in member_ids:
                 mdtool.deleteMemberData(member_id)
@@ -515,7 +508,7 @@ class MembershipTool(UniqueObject, Folder):
         # Delete members' home folders including all content items.
         if delete_memberareas:
             for member_id in member_ids:
-                 self.deleteMemberArea(member_id)
+                self.deleteMemberArea(member_id)
 
         # Delete members' local roles.
         if delete_localroles:
@@ -541,3 +534,4 @@ class MembershipTool(UniqueObject, Folder):
         return None
 
 InitializeClass(MembershipTool)
+registerToolInterface('portal_membership', IMembershipTool)
