@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2005 Zope Corporation and Contributors. All Rights Reserved.
+# Copyright (c) 2005 Zope Foundation and Contributors.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -11,8 +11,6 @@
 #
 ##############################################################################
 """Skins tool xml adapter and setup handler unit tests.
-
-$Id: test_skins.py 91368 2008-09-22 19:58:48Z jens $
 """
 
 import unittest
@@ -22,6 +20,7 @@ ZopeTestCase.installProduct('CMFCore', 1)
 import os
 
 from OFS.Folder import Folder
+from zope.component import getSiteManager
 from zope.interface import implements
 
 from Products.GenericSetup.testing import BodyAdapterTestCase
@@ -37,7 +36,7 @@ _TESTS_PATH = os.path.split(__file__)[0]
 
 _DIRECTORYVIEW_XML = """\
 <object name="foo_directoryview" meta_type="Filesystem Directory View"
-   directory="CMFCore/exportimport/tests/one"/>
+   directory="Products.CMFCore.exportimport.tests:one"/>
 """
 
 _SKINSTOOL_BODY = """\
@@ -106,9 +105,9 @@ _FRAGMENT3_IMPORT = """\
 <?xml version="1.0"?>
 <object name="portal_skins" meta_type="Dummy Skins Tool">
  <object name="three" meta_type="Filesystem Directory View"
-    directory="CMFCore/exportimport/tests/three"/>
+    directory="Products.CMFCore.exportimport.tests:three"/>
  <object name="four" meta_type="Filesystem Directory View"
-    directory="CMFCore/exportimport/tests/four"/>
+    directory="Products.CMFCore.exportimport.tests:four"/>
  <skin-path name="*">
   <layer name="three" insert-before="*"/>
   <layer name="four" insert-after="*"/>
@@ -249,7 +248,7 @@ class DirectoryViewAdapterTests(_DVRegistrySetup,
         return DirectoryViewNodeAdapter
 
     def _populate(self, obj):
-        obj._dirpath = 'CMFCore/exportimport/tests/one'
+        obj._dirpath = 'Products.CMFCore.exportimport.tests:one'
 
     def setUp(self):
         from Products.CMFCore.DirectoryView import DirectoryView
@@ -279,14 +278,13 @@ class SkinsToolXMLAdapterTests(_DVRegistrySetup,
 
         obj._setObject('foo_directoryview',
                        DirectoryView('foo_directoryview',
-                                     'CMFCore/exportimport/tests/one'))
+                                   'Products.CMFCore.exportimport.tests:one'))
         obj.addSkinSelection('foo_path', 'one')
 
     def _verifyImport(self, obj):
         pass
 
     def setUp(self):
-        from Products.CMFCore import DirectoryView
         from Products.CMFCore.SkinsTool import SkinsTool
 
         _DVRegistrySetup.setUp(self)
@@ -303,12 +301,14 @@ class _SkinsSetup(_DVRegistrySetup, BaseRegistryTests):
         from Products.CMFCore.DirectoryView import DirectoryView
 
         site = DummySite()
-        fsdvs = [ (id, DirectoryView(id, 'CMFCore/exportimport/tests/%s' %
-                                         id)) for id in ids ]
-        site._setObject('portal_skins', DummySkinsTool(selections, fsdvs))
+        fsdvs = [ (id, DirectoryView(id,
+                               'Products.CMFCore.exportimport.tests:%s' % id))
+                  for id in ids ]
+        stool = DummySkinsTool(selections, fsdvs).__of__(site)
+        getSiteManager().registerUtility(stool, ISkinsTool)
 
         site.REQUEST = 'exists'
-        return site
+        return site, stool
 
     def setUp(self):
         BaseRegistryTests.setUp(self)
@@ -326,7 +326,7 @@ class exportSkinsToolTests(_SkinsSetup):
     def test_empty(self):
         from Products.CMFCore.exportimport.skins import exportSkinsTool
 
-        site = self._initSite()
+        site, _stool = self._initSite()
         context = DummyExportContext(site)
         exportSkinsTool(context)
 
@@ -342,8 +342,8 @@ class exportSkinsToolTests(_SkinsSetup):
         _IDS = ('one', 'two', 'three')
         _PATHS = {'basic': 'one', 'fancy': 'three, two, one'}
 
-        site = self._initSite(selections=_PATHS, ids=_IDS)
-        tool = site.portal_skins
+        site, tool = self._initSite(selections=_PATHS, ids=_IDS)
+
         tool.default_skin = 'basic'
         tool.request_varname = 'skin_var'
         tool.allow_any = True
@@ -380,8 +380,8 @@ class importSkinsToolTests(_SkinsSetup):
         _IDS = ('one', 'two', 'three')
         _PATHS = {'basic': 'one', 'fancy': 'three, two, one'}
 
-        site = self._initSite(selections=_PATHS, ids=_IDS)
-        skins_tool = site.portal_skins
+        site, skins_tool = self._initSite(selections=_PATHS, ids=_IDS)
+
         self.failUnless(skins_tool._getSelections().has_key('fancy'))
 
         context = DummyImportContext(site)
@@ -397,8 +397,7 @@ class importSkinsToolTests(_SkinsSetup):
         _IDS = ('one', 'two', 'three')
         _PATHS = {'basic': 'one', 'fancy': 'three, two, one'}
 
-        site = self._initSite(selections=_PATHS, ids=_IDS)
-        skins_tool = site.portal_skins
+        site, skins_tool = self._initSite(selections=_PATHS, ids=_IDS)
 
         self.failIf(site._skin_setup_called)
         self.assertEqual(len(skins_tool.getSkinPaths()), 2)
@@ -422,8 +421,7 @@ class importSkinsToolTests(_SkinsSetup):
         _IDS = ('one', 'two', 'three')
         _PATHS = {'basic': 'one', 'fancy': 'three, two, one'}
 
-        site = self._initSite(selections=_PATHS, ids=_IDS)
-        skins_tool = site.portal_skins
+        site, skins_tool = self._initSite(selections=_PATHS, ids=_IDS)
 
         self.failIf(site._skin_setup_called)
         self.assertEqual(len(skins_tool.getSkinPaths()), 2)
@@ -447,8 +445,7 @@ class importSkinsToolTests(_SkinsSetup):
         _IDS = ('one', 'two', 'three')
         _PATHS = {'basic': 'one', 'fancy': 'three, two, one'}
 
-        site = self._initSite(selections=_PATHS, ids=_IDS)
-        skins_tool = site.portal_skins
+        site, skins_tool = self._initSite(selections=_PATHS, ids=_IDS)
 
         self.failIf(site._skin_setup_called)
         self.assertEqual(len(skins_tool.getSkinPaths()), 2)
@@ -469,8 +466,7 @@ class importSkinsToolTests(_SkinsSetup):
     def test_normal(self):
         from Products.CMFCore.exportimport.skins import importSkinsTool
 
-        site = self._initSite()
-        skins_tool = site.portal_skins
+        site, skins_tool = self._initSite()
 
         self.failIf(site._skin_setup_called)
         self.assertEqual(len(skins_tool.getSkinPaths()), 0)
@@ -494,8 +490,7 @@ class importSkinsToolTests(_SkinsSetup):
         _IDS = ('one', 'two')
         _PATHS = {'basic': 'one', 'fancy': 'two,one'}
 
-        site = self._initSite(selections=_PATHS, ids=_IDS)
-        skins_tool = site.portal_skins
+        site, skins_tool = self._initSite(selections=_PATHS, ids=_IDS)
 
         self.failIf(site._skin_setup_called)
         skin_paths = skins_tool.getSkinPaths()
@@ -539,8 +534,7 @@ class importSkinsToolTests(_SkinsSetup):
         _IDS = ('one', 'two')
         _PATHS = {'basic': 'one', 'fancy': 'two,one'}
 
-        site = self._initSite(selections=_PATHS, ids=_IDS)
-        skins_tool = site.portal_skins
+        site, skins_tool = self._initSite(selections=_PATHS, ids=_IDS)
 
         self.failIf(site._skin_setup_called)
         skin_paths = skins_tool.getSkinPaths()
@@ -571,8 +565,7 @@ class importSkinsToolTests(_SkinsSetup):
         _IDS = ('one', 'two')
         _PATHS = {'basic': 'one', 'fancy': 'two,one'}
 
-        site = self._initSite(selections=_PATHS, ids=_IDS)
-        skins_tool = site.portal_skins
+        site, skins_tool = self._initSite(selections=_PATHS, ids=_IDS)
 
         skin_paths = skins_tool.getSkinPaths()
         self.assertEqual(len(skin_paths), 2)
@@ -609,8 +602,7 @@ class importSkinsToolTests(_SkinsSetup):
         _IDS = ('one', 'two', 'three', 'four')
         _PATHS = {'basic': 'one,three,four', 'existing': 'one,two,four'}
 
-        site = self._initSite(selections=_PATHS, ids=_IDS)
-        skins_tool = site.portal_skins
+        site, skins_tool = self._initSite(selections=_PATHS, ids=_IDS)
 
         skin_paths = skins_tool.getSkinPaths()
         self.assertEqual(len(skin_paths), 2)
@@ -639,8 +631,7 @@ class importSkinsToolTests(_SkinsSetup):
         _IDS = ('one', 'two', 'three', 'four')
         _PATHS = {'existing': 'one,three,four'}
 
-        site = self._initSite(selections=_PATHS, ids=_IDS)
-        skins_tool = site.portal_skins
+        site, skins_tool = self._initSite(selections=_PATHS, ids=_IDS)
 
         skin_paths = skins_tool.getSkinPaths()
         self.assertEqual(len(skin_paths), 1)
@@ -660,23 +651,9 @@ class importSkinsToolTests(_SkinsSetup):
 
 
 def test_suite():
-    # reimport to make sure tests are run from Products
-    from Products.CMFCore.exportimport.tests.test_skins \
-            import DirectoryViewAdapterTests
-    from Products.CMFCore.exportimport.tests.test_skins \
-            import exportSkinsToolTests
-    from Products.CMFCore.exportimport.tests.test_skins \
-            import importSkinsToolTests
-    from Products.CMFCore.exportimport.tests.test_skins \
-            import SkinsToolXMLAdapterTests
-
     return unittest.TestSuite((
         unittest.makeSuite(DirectoryViewAdapterTests),
         unittest.makeSuite(SkinsToolXMLAdapterTests),
         unittest.makeSuite(exportSkinsToolTests),
         unittest.makeSuite(importSkinsToolTests),
         ))
-
-if __name__ == '__main__':
-    from Products.CMFCore.testing import run
-    run(test_suite())
