@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2002 Zope Corporation and Contributors. All Rights Reserved.
+# Copyright (c) 2002 Zope Foundation and Contributors.
 #
 # This software is subject to the provisions of the Zope Public License,
 # Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
@@ -11,8 +11,6 @@
 #
 ##############################################################################
 """ Unit tests for CachingPolicyManager module.
-
-$Id: test_CachingPolicyManager.py 77358 2007-07-03 15:18:06Z yuppie $
 """
 
 import unittest
@@ -27,17 +25,21 @@ from Acquisition import Implicit
 from App.Common import rfc1123_date
 from DateTime.DateTime import DateTime
 from OFS.Cache import Cacheable
+from zope.component import getSiteManager
 from zope.interface.verify import verifyClass
 
 from Products.CMFCore.FSDTMLMethod import FSDTMLMethod
 from Products.CMFCore.FSPageTemplate import FSPageTemplate
+from Products.CMFCore.interfaces import IMembershipTool
+from Products.CMFCore.interfaces import ITypesTool
 from Products.CMFCore.testing import FunctionalZCMLLayer
 from Products.CMFCore.testing import TraversingZCMLLayer
 from Products.CMFCore.tests.base.dummy import DummyContent
 from Products.CMFCore.tests.base.dummy import DummySite
 from Products.CMFCore.tests.base.dummy import DummyTool
 from Products.CMFCore.tests.base.testcase import FSDVTest
-from Products.CMFCore.tests.base.testcase import RequestTest
+from Products.CMFCore.tests.base.testcase import SecurityTest
+from Products.CMFCore.tests.base.testcase import TransactionalTest
 
 ACCLARK = DateTime( '2001/01/01' )
 portal_owner = 'portal_owner'
@@ -100,11 +102,13 @@ class CachingPolicyTests(unittest.TestCase):
 
     def _makeContext( self, **kw ):
         from Products.CMFCore.CachingPolicyManager import createCPContext
+
         return createCPContext( DummyContent2(self._epoch)
                               , 'foo_view', kw, self._epoch )
 
     def setUp(self):
         self._epoch = DateTime(0)
+        getSiteManager().registerUtility(DummyTool(), IMembershipTool)
 
     def test_interfaces(self):
         from Products.CMFCore.CachingPolicyManager import CachingPolicy
@@ -123,7 +127,6 @@ class CachingPolicyTests(unittest.TestCase):
                         , rfc1123_date(self._epoch.timeTime()) )
 
     def test_noPassPredicate( self ):
-
         policy = self._makePolicy( 'noPassPredicate', predicate='nothing' )
         context = self._makeContext()
         headers = policy.getHeaders( context )
@@ -131,7 +134,6 @@ class CachingPolicyTests(unittest.TestCase):
         self.assertEqual( len( headers ), 0 )
 
     def test_typePredicate( self ):
-
         policy = self._makePolicy( 'typePredicate'
                            , predicate='python:object.Type() == "Dummy"' )
         context = self._makeContext()
@@ -142,7 +144,6 @@ class CachingPolicyTests(unittest.TestCase):
         self.assertEqual( headers[0][1] , rfc1123_date(self._epoch.timeTime()) )
 
     def test_typePredicateMiss( self ):
-
         policy = self._makePolicy( 'typePredicate'
                         , predicate='python:object.Type() == "Foolish"' )
         context = self._makeContext()
@@ -151,7 +152,6 @@ class CachingPolicyTests(unittest.TestCase):
         self.assertEqual( len( headers ), 0 )
 
     def test_viewPredicate( self ):
-
         policy = self._makePolicy( 'viewPredicate'
                                  , predicate='python:view == "foo_view"' )
         context = self._makeContext()
@@ -163,7 +163,6 @@ class CachingPolicyTests(unittest.TestCase):
                         , rfc1123_date(self._epoch.timeTime()) )
 
     def test_viewPredicateMiss( self ):
-
         policy = self._makePolicy( 'viewPredicateMiss'
                            , predicate='python:view == "bar_view"' )
         context = self._makeContext()
@@ -172,7 +171,6 @@ class CachingPolicyTests(unittest.TestCase):
         self.assertEqual( len( headers ), 0 )
 
     def test_kwPredicate( self ):
-
         policy = self._makePolicy( 'kwPredicate'
                                  , predicate='python:"foo" in keywords.keys()' )
         context = self._makeContext( foo=1 )
@@ -184,7 +182,6 @@ class CachingPolicyTests(unittest.TestCase):
                         , rfc1123_date(self._epoch.timeTime()) )
 
     def test_kwPredicateMiss( self ):
-
         policy = self._makePolicy( 'kwPredicateMiss'
                                  , predicate='python:"foo" in keywords.keys()' )
         context = self._makeContext( bar=1 )
@@ -198,7 +195,6 @@ class CachingPolicyTests(unittest.TestCase):
         self.assertEqual( len( headers ), 0 )
 
     def test_mtimeFunc( self ):
-
         policy = self._makePolicy( 'mtimeFunc'
                                  , mtime_func='string:2001/01/01' )
         context = self._makeContext()
@@ -210,7 +206,6 @@ class CachingPolicyTests(unittest.TestCase):
                         , rfc1123_date(ACCLARK.timeTime()) )
 
     def test_mtimeFuncNone( self ):
-
         policy = self._makePolicy( 'mtimeFuncNone'
                                  , mtime_func='nothing' )
         context = self._makeContext()
@@ -219,7 +214,6 @@ class CachingPolicyTests(unittest.TestCase):
         self.assertEqual( len( headers ), 0 )
 
     def test_maxAge( self ):
-
         policy = self._makePolicy( 'aged', max_age_secs=86400 )
         context = self._makeContext()
         headers = policy.getHeaders( context )
@@ -235,7 +229,6 @@ class CachingPolicyTests(unittest.TestCase):
         self.assertEqual( headers[2][1] , 'max-age=86400' )
 
     def test_sMaxAge( self ):
-
         policy = self._makePolicy( 's_aged', s_max_age_secs=86400 )
         context = self._makeContext()
         headers = policy.getHeaders( context )
@@ -249,7 +242,6 @@ class CachingPolicyTests(unittest.TestCase):
         self.assertEqual(policy.getSMaxAgeSecs(), 86400)
 
     def test_noCache( self ):
-
         policy = self._makePolicy( 'noCache', no_cache=1 )
         context = self._makeContext()
         headers = policy.getHeaders( context )
@@ -264,7 +256,6 @@ class CachingPolicyTests(unittest.TestCase):
         self.assertEqual( headers[2][1] , 'no-cache' )
 
     def test_noStore( self ):
-
         policy = self._makePolicy( 'noStore', no_store=1 )
         context = self._makeContext()
         headers = policy.getHeaders( context )
@@ -277,7 +268,6 @@ class CachingPolicyTests(unittest.TestCase):
         self.assertEqual( headers[1][1] , 'no-store' )
 
     def test_mustRevalidate( self ):
-
         policy = self._makePolicy( 'mustRevalidate', must_revalidate=1 )
         context = self._makeContext()
         headers = policy.getHeaders( context )
@@ -290,7 +280,6 @@ class CachingPolicyTests(unittest.TestCase):
         self.assertEqual( headers[1][1] , 'must-revalidate' )
 
     def test_proxyRevalidate( self ):
-
         policy = self._makePolicy( 'proxyRevalidate', proxy_revalidate=1 )
         context = self._makeContext()
         headers = policy.getHeaders( context )
@@ -304,7 +293,6 @@ class CachingPolicyTests(unittest.TestCase):
         self.assertEqual(policy.getProxyRevalidate(), 1)
 
     def test_public( self ):
-
         policy = self._makePolicy( 'public', public=1 )
         context = self._makeContext()
         headers = policy.getHeaders( context )
@@ -318,7 +306,6 @@ class CachingPolicyTests(unittest.TestCase):
         self.assertEqual(policy.getPublic(), 1)
 
     def test_private( self ):
-
         policy = self._makePolicy( 'private', private=1 )
         context = self._makeContext()
         headers = policy.getHeaders( context )
@@ -332,7 +319,6 @@ class CachingPolicyTests(unittest.TestCase):
         self.assertEqual(policy.getPrivate(), 1)
 
     def test_noTransform( self ):
-
         policy = self._makePolicy( 'noTransform', no_transform=1 )
         context = self._makeContext()
         headers = policy.getHeaders( context )
@@ -346,7 +332,6 @@ class CachingPolicyTests(unittest.TestCase):
         self.assertEqual(policy.getNoTransform(), 1)
 
     def test_lastModified( self ):
-
         policy = self._makePolicy( 'lastModified', last_modified=0 )
         context = self._makeContext()
         headers = policy.getHeaders( context )
@@ -355,7 +340,6 @@ class CachingPolicyTests(unittest.TestCase):
         self.assertEqual(policy.getLastModified(), 0)
 
     def test_preCheck( self ):
-
         policy = self._makePolicy( 'preCheck', pre_check=1 )
         context = self._makeContext()
         headers = policy.getHeaders( context )
@@ -370,7 +354,6 @@ class CachingPolicyTests(unittest.TestCase):
         self.assertEqual(policy.getPostCheck(), None)
 
     def test_postCheck( self ):
-
         policy = self._makePolicy( 'postCheck', post_check=1 )
         context = self._makeContext()
         headers = policy.getHeaders( context )
@@ -385,7 +368,6 @@ class CachingPolicyTests(unittest.TestCase):
         self.assertEqual(policy.getPreCheck(), None)
 
     def test_ETag( self ):
-
         # With an empty etag_func, no ETag should be produced
         policy = self._makePolicy( 'ETag', etag_func='' )
         context = self._makeContext()
@@ -408,7 +390,6 @@ class CachingPolicyTests(unittest.TestCase):
         self.assertEqual( headers[1][1], 'foo' )
 
     def test_combined( self ):
-
         policy = self._makePolicy( 'noStore', no_cache=1, no_store=1 )
         context = self._makeContext()
         headers = policy.getHeaders( context )
@@ -427,13 +408,17 @@ class CachingPolicyManagerTests(unittest.TestCase):
 
     layer = TraversingZCMLLayer
 
-    def _makeOne(self, *args, **kw):
+    def _getTargetClass(self):
         from Products.CMFCore.CachingPolicyManager import CachingPolicyManager
 
-        return CachingPolicyManager(*args, **kw)
+        return CachingPolicyManager
+
+    def _makeOne(self, *args, **kw):
+        return self._getTargetClass()(*args, **kw)
 
     def setUp(self):
         self._epoch = DateTime()
+        getSiteManager().registerUtility(DummyTool(), IMembershipTool)
 
     def assertEqualDelta( self, lhs, rhs, delta ):
         self.failUnless( abs( lhs - rhs ) <= delta )
@@ -445,7 +430,6 @@ class CachingPolicyManagerTests(unittest.TestCase):
         verifyClass(ICachingPolicyManager, CachingPolicyManager)
 
     def test_empty( self ):
-
         mgr = self._makeOne()
 
         self.assertEqual( len( mgr.listPolicies() ), 0 )
@@ -463,7 +447,6 @@ class CachingPolicyManagerTests(unittest.TestCase):
         self.assertRaises( KeyError, mgr._reorderPolicy, 'xyzzy', -1 )
 
     def test_addAndUpdatePolicy( self ):
-
         mgr = self._makeOne()
         mgr.addPolicy('first', 'python:1', 'mtime', 1, 0, 1, 0, 'vary',
                       'etag', None, 2, 1, 0, 1, 0, 1, 0, 2, 3)
@@ -510,7 +493,6 @@ class CachingPolicyManagerTests(unittest.TestCase):
         self.assertEqual(p.getPostCheck(), 2)
 
     def test_reorder( self ):
-
         mgr = self._makeOne()
 
         policy_ids = ( 'foo', 'bar', 'baz', 'qux' )
@@ -529,7 +511,6 @@ class CachingPolicyManagerTests(unittest.TestCase):
         self.assertEqual( ids, ( 'foo', 'baz', 'qux', 'bar' ) )
 
     def _makeOneWithPolicies( self ):
-
         mgr = self._makeOne()
 
         policy_tuples = ( ( 'foo', None  )
@@ -546,7 +527,6 @@ class CachingPolicyManagerTests(unittest.TestCase):
         return mgr
 
     def test_lookupNoMatch( self ):
-
         mgr = self._makeOneWithPolicies()
         headers = mgr.getHTTPCachingHeaders( content=DummyContent2(self._epoch)
                                            , view_method='foo_view'
@@ -556,7 +536,6 @@ class CachingPolicyManagerTests(unittest.TestCase):
         self.assertEqual( len( headers ), 0 )
 
     def test_lookupMatchFoo( self ):
-
         mgr = self._makeOneWithPolicies()
         headers = mgr.getHTTPCachingHeaders( content=DummyContent2(self._epoch)
                                            , view_method='foo_view'
@@ -569,7 +548,6 @@ class CachingPolicyManagerTests(unittest.TestCase):
                         , rfc1123_date(self._epoch.timeTime()) )
 
     def test_lookupMatchBar( self ):
-
         mgr = self._makeOneWithPolicies()
         headers = mgr.getHTTPCachingHeaders( content=DummyContent2(self._epoch)
                                            , view_method='foo_view'
@@ -587,7 +565,6 @@ class CachingPolicyManagerTests(unittest.TestCase):
         self.assertEqual( headers[2][1], 'max-age=0' )
 
     def test_lookupMatchBaz( self ):
-
         mgr = self._makeOneWithPolicies()
         headers = mgr.getHTTPCachingHeaders( content=DummyContent2(self._epoch)
                                            , view_method='foo_view'
@@ -608,7 +585,6 @@ class CachingPolicyManagerTests(unittest.TestCase):
         self.assertEqual( headers[2][1] , 'max-age=3600' )
 
     def test_lookupMatchQux( self ):
-
         mgr = self._makeOneWithPolicies()
         headers = mgr.getHTTPCachingHeaders( content=DummyContent2(self._epoch)
                                            , view_method='foo_view'
@@ -629,28 +605,40 @@ class CachingPolicyManagerTests(unittest.TestCase):
         self.assertEqual( headers[2][1] , 'max-age=86400' )
 
 
-class CachingPolicyManager304Tests(RequestTest, FSDVTest):
+class CachingPolicyManager304Tests(SecurityTest, FSDVTest):
 
-    layer = FunctionalZCMLLayer
+    layer = TraversingZCMLLayer
+
+    def _getTargetClass(self):
+        from Products.CMFCore.CachingPolicyManager import CachingPolicyManager
+
+        return CachingPolicyManager
+
+    def _makeOne(self, *args, **kw):
+        return self._getTargetClass()(*args, **kw)
 
     def setUp(self):
-        from Products.CMFCore import CachingPolicyManager
+        from Products.CMFCore.interfaces import ICachingPolicyManager
 
-        RequestTest.setUp(self)
+        SecurityTest.setUp(self)
         FSDVTest.setUp(self)
 
         now = DateTime()
 
         # Create a fake portal and the tools we need
-        self.portal = DummySite(id='portal').__of__(self.root)
-        self.portal._setObject('portal_types', DummyTool())
+        self.portal = DummySite(id='portal').__of__(self.app)
+        cpm = self._makeOne()
+        sm = getSiteManager()
+        sm.registerUtility(cpm, ICachingPolicyManager)
+        sm.registerUtility(DummyTool(), IMembershipTool)
+        sm.registerUtility(DummyTool(), ITypesTool)
 
         # This is a FSPageTemplate that will be used as the View for
         # our content objects. It doesn't matter what it returns.
         path = os.path.join(self.skin_path_name, 'testPT2.pt')
         self.portal._setObject('dummy_view', FSPageTemplate('dummy_view', path))
 
-        uf = self.root.acl_users
+        uf = self.app.acl_users
         password = 'secret'
         uf.userFolderAddUser(portal_owner, password, ['Manager'], [])
         user = uf.getUserById(portal_owner)
@@ -667,9 +655,6 @@ class CachingPolicyManager304Tests(RequestTest, FSDVTest):
         self.portal.doc2.modified_date = now
         self.portal.doc3.modified_date = now
 
-        CachingPolicyManager.manage_addCachingPolicyManager(self.portal)
-        cpm = self.portal.caching_policy_manager
-
         # This policy only applies to doc1. It will not emit any ETag header
         # but it enables If-modified-since handling.
         cpm.addPolicy(policy_id = 'policy_no_etag',
@@ -710,8 +695,8 @@ class CachingPolicyManager304Tests(RequestTest, FSDVTest):
                       enable_304s = 0)
 
     def tearDown(self):
-        RequestTest.tearDown(self)
         FSDVTest.tearDown(self)
+        SecurityTest.tearDown(self)
 
     def _cleanup(self):
         # Clean up request and response
@@ -845,7 +830,6 @@ class CachingPolicyManager304Tests(RequestTest, FSDVTest):
         self._cleanup()
 
     def testConditionalGETDisabled(self):
-        yesterday = DateTime() - 1
         doc3 = self.portal.doc3
         request = doc3.REQUEST
         response = request.RESPONSE
@@ -878,23 +862,35 @@ class FSObjMaker(FSDVTest):
         path = path_join(self.skin_path_name, filename)
         return FSDTMLMethod( id, path )
 
-class NestedTemplateTests( RequestTest, FSObjMaker ):
+
+class NestedTemplateTests(TransactionalTest, FSObjMaker):
 
     layer = TraversingZCMLLayer
 
+    def _getTargetClass(self):
+        from Products.CMFCore.CachingPolicyManager import CachingPolicyManager
+
+        return CachingPolicyManager
+
+    def _makeOne(self, *args, **kw):
+        return self._getTargetClass()(*args, **kw)
+
     def setUp(self):
+        from Products.CMFCore.interfaces import ICachingPolicyManager
+
         FSObjMaker.setUp(self)
-        RequestTest.setUp(self)
+        TransactionalTest.setUp(self)
 
         # Create a fake portal and the tools we need
-        self.portal = DummySite(id='portal').__of__(self.root)
-        self.portal._setObject('portal_types', DummyTool())
-
-        from Products.CMFCore import CachingPolicyManager
-        CachingPolicyManager.manage_addCachingPolicyManager(self.portal)
+        self.portal = DummySite(id='portal').__of__(self.app)
+        self.cpm = self._makeOne()
+        sm = getSiteManager()
+        sm.registerUtility(self.cpm, ICachingPolicyManager)
+        sm.registerUtility(DummyTool(), IMembershipTool)
+        sm.registerUtility(DummyTool(), ITypesTool)
 
     def tearDown(self):
-        RequestTest.tearDown(self)
+        TransactionalTest.tearDown(self)
         FSObjMaker.tearDown(self)
 
     def test_subtemplate_cpm_1( self ):
@@ -902,7 +898,7 @@ class NestedTemplateTests( RequestTest, FSObjMaker ):
         # set up site
         portal = self.portal
         now = DateTime()
-        cpm = portal.caching_policy_manager
+        cpm = self.cpm
         cpm.addPolicy(policy_id = 'policy_op2',
                       predicate = 'python:view=="output_page_2"',
                       mtime_func = '',
@@ -937,7 +933,7 @@ class NestedTemplateTests( RequestTest, FSObjMaker ):
         # not activate the bug because RESPONSE is not passed in
         portal = self.portal
         now = DateTime()
-        cpm = portal.caching_policy_manager
+        cpm = self.cpm
         cpm.addPolicy(policy_id = 'policy_op4',
                       predicate = 'python:view=="output_page_4"',
                       mtime_func = '',
@@ -975,7 +971,7 @@ class NestedTemplateTests( RequestTest, FSObjMaker ):
         # set up site
         portal = self.portal
         now = DateTime()
-        cpm = portal.caching_policy_manager
+        cpm = self.cpm
         cpm.addPolicy(policy_id = 'policy_nv1',
                       predicate = 'python:view=="nested_view_1"',
                       mtime_func = '',
@@ -1005,7 +1001,7 @@ class NestedTemplateTests( RequestTest, FSObjMaker ):
         portal._setObject('nested_view_1', nested_view_1)
         portal._setObject('nested_view_2', nested_view_2)
 
-        data = portal.doc1()
+        portal.doc1()
 
         # no headers should be added by the CPM if all is well
         headers = [x.lower() for x in self.RESPONSE.headers.keys()]
@@ -1017,7 +1013,7 @@ class NestedTemplateTests( RequestTest, FSObjMaker ):
         # set up site
         now = DateTime()
         portal = self.portal
-        cpm = portal.caching_policy_manager
+        cpm = self.cpm
         cpm.addPolicy(policy_id = 'policy_nv1',
                       predicate = 'python:view=="nested_view_1"',
                       mtime_func = '',
@@ -1074,7 +1070,7 @@ class NestedTemplateTests( RequestTest, FSObjMaker ):
             doc.modified_date = modified_date
             self.portal._setObject(id, doc)
 
-        cpm = self.portal.caching_policy_manager
+        cpm = self.cpm
 
         # This policy only applies to doc2.
         cpm.addPolicy(policy_id = 'policy_doc2',
@@ -1136,7 +1132,7 @@ class NestedTemplateTests( RequestTest, FSObjMaker ):
             doc.modified_date = modified_date
             self.portal._setObject(id, doc)
 
-        cpm = self.portal.caching_policy_manager
+        cpm = self.cpm
 
         # This policy only applies to doc1.
         cpm.addPolicy(policy_id = 'policy_doc1',
@@ -1197,37 +1193,55 @@ class NestedTemplateTests( RequestTest, FSObjMaker ):
                          )
 
 
-class OFSCacheTests(RequestTest):
+class OFSCacheTests(TransactionalTest):
 
     layer = FunctionalZCMLLayer
 
-    def setUp(self):
-        from Products.CMFCore import CachingPolicyManager
+    def _getTargetClass(self):
+        from Products.CMFCore.CachingPolicyManager import CachingPolicyManager
 
-        RequestTest.setUp(self)
+        return CachingPolicyManager
+
+    def _makeOne(self, *args, **kw):
+        return self._getTargetClass()(*args, **kw)
+
+    def setUp(self):
+        from Products.CMFCore.interfaces import ICachingPolicyManager
+
+        TransactionalTest.setUp(self)
 
         # Create a fake portal and the tools we need
-        self.portal = DummySite(id='portal').__of__(self.root)
+        self.portal = DummySite(id='portal').__of__(self.app)
         self.portal._setObject('doc1', CacheableDummyContent('doc1'))
         self.portal._setObject('doc2', CacheableDummyContent('doc2'))
-        CachingPolicyManager.manage_addCachingPolicyManager(self.portal)
-        cpm = self.portal.caching_policy_manager
+        cpm = self._makeOne()
+        self.portal._setObject('caching_policy_manager', cpm)
+        sm = getSiteManager()
+        sm.registerUtility(cpm, ICachingPolicyManager)
+        sm.registerUtility(DummyTool(), IMembershipTool)
 
         # This policy only applies to doc1. It will not emit any ETag header
         # but it enables If-modified-since handling.
-        cpm.addPolicy(policy_id = 'policy_1',
-                      predicate = 'python:object.getId()=="doc1"',
-                      mtime_func = '',
-                      max_age_secs = 100,
-                      no_cache = 0,
-                      no_store = 0,
-                      must_revalidate = 0,
-                      vary = 'doc1',
-                      etag_func = '',
-                      enable_304s = 0)
+        cpm.addPolicy(policy_id='policy_1',
+                      predicate='python:object.getId()=="doc1"',
+                      mtime_func='',
+                      max_age_secs=100,
+                      no_cache=0,
+                      no_store=0,
+                      must_revalidate=0,
+                      vary='doc1',
+                      etag_func='',
+                      enable_304s=0)
+
+    def tearDown(self):
+        from Products.CMFCore.interfaces import ICachingPolicyManager
+
+        sm = getSiteManager()
+        sm.unregisterUtility(provided=ICachingPolicyManager)
+        sm.unregisterUtility(provided=IMembershipTool)
+        TransactionalTest.tearDown(self)
 
     def test_empty(self):
-
         from Products.CMFCore.CachingPolicyManager import CPMCache
 
         cpm = self.portal.caching_policy_manager
@@ -1314,7 +1328,3 @@ def test_suite():
         unittest.makeSuite(NestedTemplateTests),
         unittest.makeSuite(OFSCacheTests),
         ))
-
-if __name__ == '__main__':
-    from Products.CMFCore.testing import run
-    run(test_suite())
